@@ -57,7 +57,10 @@ struct ExecutionTime{
 	long double init;
 	long double iter;
 	long double initIter;
-	long double initIterSave;
+	long double ort;
+	long double cut;
+	long double ort_after_cut;
+	long double total;
 };
 
 struct XJAddress{
@@ -74,7 +77,9 @@ struct Edge{
  /* Structure for all the needed parameters (input plus state variables)
  */
 struct Environment {
-
+	ExecutionTime execTime;
+	int seed;
+	
 	int nThreads;
 	MemorySpace m;
 	std::vector<int> steps;
